CbModel class

Mixed-in types
Annotations
  • @MappableClass.new()

Constructors

CbModel(String name, String id)

Properties

copyWith → CbModelCopyWith<CbModel, CbModel, CbModel>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
inherited
toMap() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited