RestaurantModelCopyWith<$R, $In extends RestaurantModel, $Out> class abstract

Available extensions

Constructors

RestaurantModelCopyWith()

Properties

$asRestaurantModel RestaurantModelCopyWith<$R, RestaurantModel, $Out>

Available on ObjectCopyWith<$R, RestaurantModel, $Out>, provided by the RestaurantModelValueCopy extension

no setter
hashCode int
The hash code for this object.
no setterinherited
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$chain<$R2, $Out2>(Then<$Out2, $R2> t) RestaurantModelCopyWith<$R2, $In, $Out2>
$delta(Map<String, dynamic> delta) → $R
inherited
$merge($In value) → $R
inherited
$update($Out transform($In)) → $R
inherited
call({int? id, String? name, String? description, String? shortDescription, CrousType? type, double? lat, double? lon, String? opening, List<MenuCrous>? menus, String? imageUrl}) → $R
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited